@@ -106,7 +106,7 @@ class GetLatestTinderbox(object):
              'win32': 'win32',
              'win64': 'win64-x86_64',
              'macosx': 'mac',
-             'macosx64': 'mac64',
+             'macosx64': 'mac',
              }
     return regex[self.platform]
 
@@ -362,6 +362,8 @@ def main(args=sys.argv[1:]):
     latest = latest_tinderbox.latest_symbols_url(options.url)
   else:
     latest = latest_tinderbox.latest_build_url(options.url)
+  if latest is None:
+    sys.exit(1)
   print latest
 
 if __name__ == '__main__':
